import { BlockQuoteB } from "../components/Quotes";
import { Section } from "../components/sections";
import { useTabNavigation } from "../utils/TabNavigation";

export function Judging() {
  useTabNavigation();
    return (
      <>
        <Section title="Overview" id="Overview">
          <BlockQuoteB text="Judging for iGEM is one of the highlights on my professional calendar…" cite="Dr. Nancy Burgess, Director of Judging at iGEM HQ"/>
          <p>The iGEM competition celebrates innovation in synthetic biology, offering teams the chance to compete for a range of awards based on their achievements in 
            various categories. Judging is based on how well teams integrate scientific rigor with societal impact, safety, and creativity. We aim to compete for 
            several prestigious awards, including <b>Best Integrated Human Practices</b>, <b>Biosafety and Security</b> Award, and <b>Best New Basic Part</b>. Additionally, we seek recognition for our <b>therapeutic project</b> and will strive for excellence in best wiki, best promotional video, and the iGEMers prize. </p>
            <div className="row align-items-center">
              <div className="col">
                <img src="https://static.igem.wiki/teams/5247/photos/other/therapeutic-award.svg" />
              </div>
              <div className="col">
                <img src="https://static.igem.wiki/teams/5247/photos/other/ihp-award.svg" />
              </div>
              <div className="col">
                <img src="https://static.igem.wiki/teams/5247/photos/other/safety-award.svg" />
              </div>
              <div className="col">
                <img src="https://static.igem.wiki/teams/5247/photos/other/basic-part-award.svg" />
              </div>
              <div className="col">
                <img src="https://static.igem.wiki/teams/5247/photos/other/wiki-award.svg" />
              </div>
            </div>
        </Section>
        <div className="row align-items-center">
          <div className="col">
          <iframe title="Bielefeld-CeBiTec: Introduction (2024) [English]" width="560" height="315" src="https://video.igem.org/videos/embed/9ffc5914-df86-4ba7-a0eb-f324694988ee" frameBorder="0" allowFullScreen={true} sandbox="allow-same-origin allow-scripts allow-popups allow-forms"></iframe>
       
          </div>
        </div>
        <Section title="Best Therapeutic Project" id="Best Therapeutic Project">
          <p>Our project is a dual therapeutic approach targeting cystic fibrosis (CF), specifically the most common mutation, F508del. We aim to develop a curative solution by correcting the genetic defect using Prime Editing Technology while enhancing the folding of the CFTR protein. Additionally, we developed a Lipid Nanoparticle for the cell-specific targeting of lung epithelial cells. This project directly addresses the unmet therapeutic needs of CF patients, providing a long-term and potentially curative solution. </p>
          <h4>Has the team clearly defined the therapeutic problem they are addressing? </h4>
          <p>We are addressing Cystic Fibrosis (CF), a severe genetic disorder caused by mutations in the CFTR gene, particularly the F508del mutation. This mutation leads to thick mucus accumulation in vital organs, causing chronic infections and damage, particularly in the lungs. Our focus on the F508del mutation, which affects around 90 % of CF patients in Europe and beyond, ensures our project targets a well-defined and widespread therapeutic need. </p>
          <h4>How well is the therapeutic mechanism of action understood and demonstrated? </h4>
          <p>Our project employs a dual approach: </p>
          <ol>
            <li>orrecting the F508del mutation using our Prime Editing Technology	PrimeGuide, a well understood gene editing tool designed to repair defective genes</li>
            <li>delivering of our mRNA therapeutic via specialized Lipid Nanoparticles AirBuddy, ensuring direct application in lung epithelial cells</li>
          </ol>
          <h4>Has the team validated the effectiveness of their therapeutic approach? </h4>
          <p>We tested the therapeutic efficacy <i>in vitro</i> using patient-derived primary epithelial cells in Air Liquid Culture (ALI) and Apical-Out Organoids carrying the F508del mutation. These cells were treated with PreCyse to assess the genetic correction, while downstream applications will validate the improved folding and function of the CFTR protein. Our experimental design allows us to gather proof-of-concept data, demonstrating the viability of both gene correction and efficient delivery. </p>
          <h4>Does the project consider off-target effects or unintended consequences?</h4>
          <p>By incorporating FANZOR, a new eukaryotic RNA-binding DNA-endonucleases, we enhance the precision of Prime Editing. Site-directed mutagenesis enable nickasification of our CasX and FANZOR candidates. This enables the usage as Prime Editor, while enhancing efficiency and decreasing PE complex size. We have designed our system to minimize unintended consequences, ensuring that our therapeutic intervention is safe for clinical application. </p>
          <h4>What potential does the project have for real-world therapeutic applications? </h4>
          <p>Our dual approach has significant potential for real-world therapeutic applications. PreCyse provides a curative genetic solution, improve immediate physiological functions. The project addresses a crucial need in CF therapy by targeting both the root genetic cause and the resulting protein dysfunction, offering a more comprehensive solution than current treatments. </p>
          <h4>How well did the team integrate safety into their therapeutic design? </h4>
          <p>Safety is a priority in our project. The use of FANZOR enhances the specificity of our gene-editing approach, reducing the likelihood of off-target gene modifications. Additionally, we are committed to rigorous <i>in vitro</i> testing before advancing to <i>in vivo</i> models, ensuring that our therapeutic interventions do not pose risks to patients. For this, we developed an CF-specific fluorescence-based Reporter System mimicking the CF-specific genomic alteration. </p>
          <h4>To what extent has the team considered patient impact? </h4>
          <p>We have closely aligned our project with patient needs by targeting the F508del mutation, which affects a significant portion of CF patients worldwide. Our therapeutic solution aims to improve quality of life by addressing the root cause of CF and reducing the burden of lifelong treatments. We are also in contact with CF patients and have gathered insights from healthcare providers to ensure our therapy is patient-centric. PreCyse offers a long-time solution, while being cost-efficient and easy-to-use. </p>
          <p>Our innovative therapeutic project leverages the power of gene editing and protein modulation to offer a potentially curative solution for Cystic Fibrosis, particularly for the prevalent F508del mutation. With a well-validated scientific foundation, comprehensive safety measures, and a strong focus on patient needs, we believe our project exemplifies the qualities deserving of the <b>Best Therapeutic Project Award</b>. Our dual approach provides a template for future genetic disease treatments, paving the way for more effective and personalized medical solutions. </p>
        </Section>
        <Section title="Best Integrated Human Practice" id="Best Integrated Human Practice">
          <p>Our team’s project at Bielefeld-CeBiTec integrates Human Practices into every aspect of our work, ensuring that our synthetic biology innovation aligns with societal needs, ethical considerations, and environmental sustainability. By proactively engaging with a broad range of stakeholders, including scientists, regulatory bodies, and community groups, we shaped our project to have meaningful and responsible impacts. Our commitment to understanding the broader implications of our work positions us as a strong candidate for the <b>Best Integrated Human Practices Award</b>. </p>
          <h4>Integration of Human Practices </h4>
          <p>We actively engaged with a diverse array of stakeholders throughout our project, from CF patients like Max Beckmann[Link] to clinicians such as Prof. Dr. Olariu [Link], physiotherapists like Katrin Westhoff [Link], and industry experts including Dr. Benjamin Winkeljann [Link] and Dr. Katharina Kolonko [Link]. Each of these collaborations directly informed and shaped our therapeutic solution. Max Beckmann’s firsthand experience provided us with invaluable insights into the daily challenges of living with CF, helping us align our gene therapy with patient needs. Additionally, clinicians and physiotherapists guided us toward a treatment strategy that is practical, accessible, and effective for different patient demographics. </p>
          <h4>Inspiration to Others </h4>
          <p>Our project serves as a model for how synthetic biology can be leveraged to meet real-world needs while maintaining a patient-centered focus. By integrating feedback from patients and medical professionals, we demonstrate that cutting-edge science can coexist with empathy and responsibility. Our focus on inclusivity, scalability, and addressing global disparities in CF treatment sets a precedent for future iGEM teams looking to make a meaningful impact on health challenges. </p>
          <h4>Documentation for Future Teams </h4>
          <p>We have meticulously documented every aspect of our Human Practices integration, providing future teams with a clear roadmap for how to incorporate stakeholder feedback into a therapeutic project. This includes detailed case studies on our interactions with CF patients, medical professionals, and industry experts, along with the adjustments made to our project based on their input. Our thorough documentation ensures that others can learn from our approach and build upon our findings. </p>
          <h4>Thoughtful Implementation </h4>
          <p>Our project has been deeply informed by ethical, environmental, and societal considerations. For example, our consultation with Prof. Dr. Olariu emphasized the importance of mental health in CF care, leading us to incorporate psychosocial elements into our therapy design. Additionally, we aligned our solution with global healthcare disparities, ensuring our gene therapy can benefit underrepresented populations. Through engagement with regulatory bodies, we ensured that our project complies with all relevant biosafety and legal standards. </p>
          <h4>Incorporation of Diverse Stakeholder Views </h4>
          <p>We engaged with a broad range of stakeholders, including patients, healthcare providers, researchers, and regulatory experts, ensuring that each perspective played a role in shaping the final therapeutic solution. For instance, feedback from physiotherapist Katrin Westhoff confirmed the necessity of an inhalation-based therapy that is easy for younger patients to use. Collaborations with industry experts like Dr. Benjamin Winkeljann enabled us to optimize the technical aspects of our treatment for scalability and environmental sustainability. </p>
          <h4>Creating a Responsible and Beneficial Project </h4>
          <p>Our gene therapy for CF addresses not only the scientific challenges but also the societal need for accessible, patient-centered healthcare solutions. By incorporating human practices at every stage, we ensured that our project is ethically responsible and beneficial to society. The feedback from diverse stakeholders helped us refine our approach, ensuring that the solution is sustainable, inclusive, and addresses the global disparities in CF care. The long-term positive impact on the CF community—both in terms of health outcomes and accessibility—demonstrates our project’s commitment to responsible innovation. </p>
          <p>Our project exemplifies the seamless integration of Human Practices into every aspect of synthetic biology research. Through collaborations with patients, healthcare professionals, and experts across different fields, we have developed a gene therapy for cystic fibrosis that is scientifically innovative, ethically sound, and deeply aligned with the needs of the global CF community. Our commitment to inclusivity, ethical reflection, and environmental sustainability makes us a strong candidate for the <b>Best Integrated Human Practices Award</b>, showcasing our dedication to responsible and impactful synthetic biology. </p>
        </Section>
        <Section title="Safety & Security" id="Safety & Security">
          <p>Our project focuses on advancing biosafety and biosecurity in synthetic biology through the development and implementation of robust safety mechanisms. As part of our PreCyse project, aimed at developing a prime-editing complex to correct the F508del mutation in cystic fibrosis (CF), we place great emphasis on safety at every stage of research. With a commitment to responsible innovation, we have ensured that all phases of our work adhere to the highest safety standards, aiming to minimize both environmental and human health risks. Our approach incorporates novel containment systems, rigorous validation processes, and carefully planned checkpoints during experiments to push the boundaries of biosafety in synthetic biology. </p>
          <h4>Contribution to Biosafety and Biosecurity </h4>
          <p>We developed a comprehensive biosafety plan to minimize risks associated with our synthetic biology project. This includes biocontainment measures and protocols to prevent the accidental release of genetically modified organisms (GMOs) into the environment. By integrating both physical and genetic safeguards, we have ensured that our project contributes to safer synthetic biology applications. For example, our final construct will be tested in primary cultures of nasal epithelial cells from CF patients and healthy individuals, with carefully planned checkpoints for continuous monitoring and timely adjustments. </p>
          <p>As part of our commitment to advancing safe and ethical practices in synthetic biology and patient care, we have made several key contributions to support our project and the wider community. Firstly, we developed a <b>questionnaire to evaluate the medical history of cystic fibrosis (CF) patients</b>, which has been specifically adapted for the collection of primary human nasal epithelial cells (hNECs). This tool ensures that essential health information is gathered in a systematic and ethical manner, aiding the accurate collection of samples while safeguarding patient well-being.  </p>
          <p>Secondly, we created <b>Best Practices for safe primary culture handling</b>. This guide outlines the necessary safety protocols for working with primary cell cultures, ensuring that all procedures are conducted with minimal risk of contamination and exposure to harmful pathogens. These practices promote safety for both laboratory personnel and the integrity of the biological materials.</p>
          <p>Additionally, we developed a <b>Hygiene Concept for Immunocompromised Individuals</b> in consultation with a CF patient. This concept addresses the specific needs of individuals with weakened immune systems, such as those with CF, HIV, or certain cancers. It focuses on reducing health risks in high-foot-traffic public spaces, especially public restrooms, by implementing tailored hygiene measures. These guidelines aim to protect immunocompromised individuals by creating safer environments within university settings and beyond, contributing to broader public health initiatives. </p>
          <h4>Characterization and Validation </h4>
          <p>We rigorously tested the safety mechanisms built into our project like the disruption of the PAM sequence and pegRNA design. These mechanisms were validated through controlled experiments, ensuring reliable performance under various conditions. Furthermore, to ensure the safety and precision of our results, we introduced a series of carefully planned experimental milestones. These allow for the continuous validation of the Prime Editing complex, addressing potential issues immediately, which minimizes risk and improves the overall quality of our work. </p>
          <h4>Building on Existing Knowledge </h4>
          <p>Our work builds upon established biosafety frameworks, specifically improving known genetic containment systems. We incorporated lessons from previous iGEM teams and academic research to refine these tools, making them more effective in controlling gene flow and reducing unintended consequences. By drawing from the existing knowledge base, we ensured our biosafety mechanisms, such as riboswitch and PAM disruption, are both scalable and reliable, significantly advancing biosafety technologies. </p>
          <h4>Risk Management </h4>
          <p>From the outset, we conducted a thorough risk assessment to identify potential hazards, including those associated with handling GMOs and gene transfer. In response, we implemented stringent lab protocols and biocontainment systems to ensure the safety of our team and the surrounding environment. This risk management approach extends throughout the lifecycle of the project, from the design to the final validation stages. We also adhered to good laboratory practices, such as sterilization and controlled access, which ensures compliance with all relevant biosafety regulations. </p>
          <h4>Real-World Applications </h4>
          <p>We designed our project with real-world biosafety concerns in mind, particularly the potential environmental impact of GMOs. Our approach ensures that our technology can be safely applied outside the lab, with biocontainment strategies that prevent unintended release. For instance, by designing lipid nanoparticles (LNPs) that selectively fuse with lung epithelial cells, we reduce the risk of unwanted off-target interactions. Additionally, we considered dual-use concerns, ensuring our technology cannot be easily misappropriated for harmful purposes, making our project a model for responsible synthetic biology. </p>
          <h4>Check-Ins and iGEM Compliance </h4>
          <p>In alignment with iGEM’s emphasis on biosafety, we submitted Check-Ins for the components and organisms not covered by the iGEM White list. These formal evaluations ensured that all aspects of our project were thoroughly assessed and approved by the iGEM Safety Committee. We maintained active communication with the committee to ensure compliance with all iGEM standards, reflecting our dedication to biosafety and biosecurity. </p>
          <h4>Laboratory and Safety Practices </h4>
          <p>All experiments were conducted at Bielefeld University in Prof. Dr. Kristian Müller's laboratory, following BSL-1 (and BSL-2 if needed) standard operating procedures. The team participated in mandatory safety briefings and adhered to rigorous safety measures, including regulations concerning hazardous substances, genetic engineering, and the handling of biological materials. Our lab activities were meticulously planned to minimize risk and ensure data integrity. </p>
          <p>By building on existing knowledge, rigorously testing our biosafety measures, and proactively managing risks, we have developed a project that significantly contributes to the field of biosafety and biosecurity. Our comprehensive approach ensures that our technology can be safely applied in real-world scenarios, and we believe this sets a new standard for responsible synthetic biology. Our efforts, particularly in the development of the Prime Editing complex for CF and the associated biosafety protocols, merit recognition for the <b>Biosafety and Security Award</b>. </p>
        </Section>
        <Section title="Best New Basic Part" id="Best New Basic Part">
          <p>Our project focuses on optimizing prime editing for the cystic fibrosis-causing CFTR F508del mutation, which represents one of the most significant applications for prime editing. Prime editing is a precise and safe gene editing technique, but its efficiency varies greatly depending on the genomic locus. Through our development of a context-specific Prime Editor Activity Reporter (PEAR) system, we have successfully optimized this advanced technology, paving the way for more effective genomic targeting, not just for cystic fibrosis but for future synthetic biology applications as well. </p>
          <h4> Engineering and Testing for Contextual Precision </h4>
          <p>The challenges posed by low editing efficiency and the difficulty in distinguishing successful edits from background noise led us to design a highly sensitive reporter system. After an initial unsuccessful attempt using a fluorescent reporter, we shifted to the PEAR system proved to be much more adaptable and relevant to our needs. </p>
          <h4>Iterative Development </h4>
          <p>In our first attempt, we explored a fluorescence-based reporter that targeted GFP. While this helped us visualize prime editing in action, we quickly realized that the distance of the mutation site from the PAM sequence in the CFTR gene meant that this system wasn’t suitable for our specific genomic target. We then moved to the PEAR system, which was more flexible and sensitive, as its editing factors aligned with those required for genomic contexts. </p>
          <p>Through multiple iterations, including tests in HEK293 cells, epithelial cells, and human-derived primary cells, we refined our system. Our experiments proved the successful use of the PEAR reporter in detecting prime editing activity for CFTR F508del with minimal noise, making it ideal for detecting edits in specific genomic loci with high sensitivity. </p>
          <h4>Modularity and Broader Applications </h4>
          <p>Recognizing the limitations of the original PEAR plasmid, especially in terms of modification flexibility and compatibility with BioBrick standards, we created a more modular and accessible system. Our new version includes an oligonucleotide-based golden gate cloning site, enabling quick modification and broader applications to other genomic targets and prime editor variants. </p>
          <p>Our updated PEAR system is now compatible with RFC[1000] standards, offering future iGEM teams a versatile tool that can be applied to a wide range of editing scenarios. This is not only a significant advancement for CFTR-related research but also for any gene editing project requiring high precision and sensitivity. </p>
          <h4>Contribution to the Synthetic Biology Community </h4>
          <p>We believe our part contributes significantly to the synthetic biology community by providing an optimized system that can be easily adapted to various gene editing contexts. By improving the modularity and ease of use, we are confident that this part will be a valuable tool for future teams looking to optimize their own prime editing approaches. </p>
          <p>Our work has demonstrated that prime editing can be made more efficient and reliable, especially in difficult-to-edit regions like CFTR. Through rigorous testing and validation, we ensured that our part meets high standards for both experimental reliability and community utility. As a result, we position ourselves as strong candidates for the <b>Best New Basic Part Award</b>.</p>
        </Section>
        <Section title="Conclusion" id="Conclusion">
          <p>In conclusion, our project exemplifies the best of synthetic biology, combining cutting-edge science with ethical responsibility and a deep 
            commitment to societal impact. By integrating human practices into every stage of our work, ensuring the highest standards of biosafety, and contributing 
            valuable tools to the community, we have set a new standard for innovation in the field. Our therapeutic approach for cystic fibrosis has the potential 
            to revolutionize treatment for this life-threatening condition, while our contributions to biosafety and part development will benefit the broader 
            synthetic biology ecosystem. We are confident that our project is deserving of recognition in multiple award categories, including <b>Best Therapeutic Project</b>, <b>Best Integrated Human Practices</b>, <b>Biosafety and Security</b>, and <b>Best New Basic Part</b>. Through our work, we hope to inspire future iGEM teams to pursue solutions that are both scientifically excellent and socially responsible. </p>
        </Section>

      </>
    );
  }
  